RateLimitRejectedException class final
Thrown when a rate limiter rejects execution.
- Implemented types
Constructors
- RateLimitRejectedException({String message = 'Rate limiter rejected execution', Duration? retryAfter})
-
Creates a rate-limit rejection exception.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
final
- retryAfter → Duration?
-
Duration after which the caller may retry, when known.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited