StrategyOutcomeResult<T> class final

A successful strategy outcome.

Inheritance

Constructors

StrategyOutcomeResult(T result, {required RetryPipelineContext<T> context, Duration? elapsed, Map<String, Object?> metadata = const {}})

Properties

context RetryPipelineContext<T>
Shared pipeline execution context.
finalinherited
elapsed Duration
Elapsed pipeline time when this outcome was observed.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, Object?>
Strategy-specific metadata associated with this outcome.
finalinherited
result → T
Result returned by the wrapped execution.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited