CircuitHalfOpenContext class final
Metadata provided when an open circuit moves to half-open.
Constructors
-
CircuitHalfOpenContext({required RetryPipelineContext<
Object?> pipelineContext}) -
Creates circuit half-open metadata.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pipelineContext
→ RetryPipelineContext<
Object?> -
Execution context that observed the half-open transition.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited