CircuitOpenException class final
Thrown when a circuit breaker rejects execution.
- Implemented types
Constructors
- CircuitOpenException([String message = 'Circuit breaker is open', Duration? retryAfter])
-
Creates a circuit-open exception.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
final
- retryAfter → Duration?
-
Duration after which the circuit may allow a probe, when known.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited